#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['ynab_csv_converter', 'ynab_csv_converter.formats']

package_data = \
{'': ['*']}

install_requires = \
['pyyaml >= 3.10', 'jsonschema >= 2.3.0', 'docopt >= 0.6.1']

extras_require = \
{'test': ['tox', 'flake8']}

entry_points = \
{'console_scripts': ['ynab-csv-converter = ynab_csv_converter.__main__:main']}

setup(name='ynab-csv-converter',
      version='0.0.9',
      description='ynab-csv-converter',
      author='Anders Ingemann',
      author_email='anders@ingemann.de',
      url='https://github.com/andsens/ynab-csv-converter',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.5',
     )
